@@ -1,8 +1,11 @@
-#ifndef lint
-static char const 
-sun_map_rcsid[] = "$FreeBSD: src/usr.bin/yacc/skeleton.c,v 1.28.2.1 2001/07/19 05:46:39 peter Exp $";
-#endif
 #include <stdlib.h>
+#ifndef lint
+#ifdef __unused
+__unused
+#endif
+static char const 
+sun_map_rcsid[] = "$FreeBSD: src/usr.bin/yacc/skeleton.c,v 1.37 2003/02/12 18:03:55 davidc Exp $";
+#endif
 #define YYBYACC 1
 #define YYMAJOR 1
 #define YYMINOR 9
@@ -103,7 +106,7 @@ static struct sun_list *get_sun_entry_list();
 typedef union {
   char strval[2048];
 } YYSTYPE;
-#line 107 "sun_map_parse.c"
+#line 110 "sun_map_parse.c"
 #define YYERRCODE 256
 #define NEWLINE 257
 #define COMMENT 258
@@ -372,7 +375,7 @@ get_sun_opt_list(void)
   }
   return sun_opt_list;
 }
-#line 376 "sun_map_parse.c"
+#line 379 "sun_map_parse.c"
 /* allocate initial stack or double stack size, up to YYMAXDEPTH */
 static int sun_map_growstack()
 {
@@ -434,9 +437,9 @@ int
 sun_map_parse (YYPARSE_PARAM_ARG)
     YYPARSE_PARAM_DECL
 {
-    register int sun_map_m, sun_map_n, sun_map_state;
+    int sun_map_m, sun_map_n, sun_map_state;
 #if YYDEBUG
-    register const char *sun_map_s;
+    const char *sun_map_s;
 
     if ((sun_map_s = getenv("YYDEBUG")))
     {
@@ -865,7 +868,7 @@ case 28:
   }
 }
 break;
-#line 869 "sun_map_parse.c"
+#line 872 "sun_map_parse.c"
     }
     sun_map_ssp -= sun_map_m;
     sun_map_state = *sun_map_ssp;
