@@ -6,14 +6,14 @@
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "freebsd5.3"
+#define HOST_OS "freebsd5.4"
 #define HOST_OS_NAME "freebsd5"
-#define HOST_OS_VERSION "5.3"
+#define HOST_OS_VERSION "5.4"
 #define HOST_ARCH "i386"
 #define DISTRO_NAME "none"
-#define HOST_NAME "a-freebsd53.fsl.cs.sunysb.edu"
+#define HOST_NAME "a-freebsd54.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Thu May 11 11:27:43 EDT 2006"
+#define CONFIG_DATE "Tue Oct 18 13:50:24 EDT 2005"
 #define PACKAGE_NAME "am-utils"
 #define PACKAGE_VERSION "6.2a2"
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
@@ -34,7 +34,7 @@
 #ifdef __cplusplus
 #include <stdlib.h>
 #endif
-#define HOST_HEADER_VERSION "5.3"
+#define HOST_HEADER_VERSION "5.4"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_UNISTD_H 1
@@ -240,7 +240,6 @@
 #define HAVE_TIME_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_HESIOD_H 1
-#define NEW_DBM_H "ndbm.h"
 #define TIME_WITH_SYS_TIME 1
 #define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_freebsd3.h"
 #define HAVE_STRUCT_NFS_ARGS 1
@@ -322,8 +321,6 @@
 #define HAVE_MAP_SUN 1
 #define HAVE_MAP_EXEC 1
 #define HAVE_MAP_HESIOD 1
-#define HAVE_DBM_OPEN 1
-#define HAVE_MAP_NDBM 1
 #define HAVE_MAP_NIS 1
 #define HAVE_MAP_PASSWD 1
 #define HAVE_MAP_UNION 1
@@ -387,9 +384,6 @@
 #define MNT2_CDFS_OPT_EXTATT 0x4
 #define MNT2_CDFS_OPT_GENS 0x2
 #define MNT2_CDFS_OPT_NORRIP 0x1
-#define MNT2_PCFS_OPT_LONGNAME 0x2
-#define MNT2_PCFS_OPT_NOWIN95 0x4
-#define MNT2_PCFS_OPT_SHORTNAME 0x1
 #define HIDE_MOUNT_TYPE "nfs"
 #define USE_CONNECTED_NFS_SOCKETS 1
 #define HAVE_LIBWRAP 1
